@@ -74,22 +74,30 @@ def clear_includes_and_imports(node):
 def resolve_ref(node, params, options):
     content = None
     url = node.get('schemaLocation')
-    schema_name = os.path.split(url)[1]
-    if schema_name not in params.already_processed:
-        params.already_processed.add(schema_name)
-        if params.base_url and not (
-            url.startswith('/') or
-            url.startswith('http:') or
-            url.startswith('ftp:')
-            ):
-            locn = '%s/%s' % (params.base_url, url, )
-        else:
-            locn = url
-        if locn is not None:
-            ##             print 'trace --'
-            ##             print '    base  : %s' % (params.base_url, )
-            ##             print '    parent: %s' % (params.parent_url, )
-            ##             print '    locn  : %s' % (locn, )
+    if not url:
+        msg = '*** Warning: missing "schemaLocation" attribute in %s\n' % (
+            params.parent_url, )
+        sys.stderr.write(msg)
+        return None
+    # Uncomment the next line to help track down missing schemaLocation etc.
+    # print '(resolve_ref) url: %s\n    parent-url: %s' % (url, params.parent_url, )
+
+    if params.base_url and not (
+        url.startswith('/') or
+        url.startswith('http:') or
+        url.startswith('ftp:')
+        ):
+        locn = '%s/%s' % (params.base_url, url, )
+    else:
+        locn = url
+    if locn is not None:
+        schema_name = os.path.split(locn)
+        if schema_name not in params.already_processed:
+            params.already_processed.add(schema_name)
+##             print 'trace --'
+##             print '    base  : %s' % (params.base_url, )
+##             print '    parent: %s' % (params.parent_url, )
+##             print '    locn  : %s' % (locn, )
             if locn.startswith('http:') or locn.startswith('ftp:'):
                 try:
                     urlfile = urllib2.urlopen(locn)
@@ -131,7 +139,7 @@ def collect_inserts_aux(child, params, inserts, options):
     save_base_url = params.base_url
     string_content = resolve_ref(child, params, options)
     if string_content is not None:
-        root = etree.fromstring( string_content, base_url=params.base_url)
+        root = etree.fromstring(string_content, base_url=params.base_url)
         for child1 in root:
             if not isinstance(child1, etree._Comment):
                 namespace = child1.nsmap[child1.prefix]
