@@ -5,7 +5,6 @@
 #
 
 import sys
-from string import lower as str_lower
 
 import out2sup as supermod
 
@@ -80,7 +79,7 @@ supermod.people.subclass = peopleSub
 
 class commentsSub(supermod.comments):
     def __init__(self, emp=None, valueOf_=None, mixedclass_=None, content_=None):
-        super(commentsSub, self).__init__(valueOf_, mixedclass_, content_, )
+        super(commentsSub, self).__init__(emp, valueOf_, mixedclass_, content_, )
 supermod.comments.subclass = commentsSub
 # end class commentsSub
 
@@ -168,6 +167,9 @@ def parse(inFilename):
     doc = parsexml_(inFilename)
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
+    if rootClass is None:
+        rootTag = 'people'
+        rootClass = supermod.people
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
     # Enable Python to collect the space used by the DOM.
@@ -184,6 +186,9 @@ def parseString(inString):
     doc = parsexml_(StringIO(inString))
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
+    if rootClass is None:
+        rootTag = 'people'
+        rootClass = supermod.people
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
     # Enable Python to collect the space used by the DOM.
@@ -198,6 +203,9 @@ def parseLiteral(inFilename):
     doc = parsexml_(inFilename)
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
+    if rootClass is None:
+        rootTag = 'people'
+        rootClass = supermod.people
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
     # Enable Python to collect the space used by the DOM.
